@@ -30,9 +30,7 @@ void IdentityModel::reloadUoidList()
     endResetModel();
 }
 
-IdentityModel::~IdentityModel()
-{
-}
+IdentityModel::~IdentityModel() = default;
 
 QVariant IdentityModel::data(const QModelIndex &index, int role) const
 {
@@ -50,6 +48,10 @@ QVariant IdentityModel::data(const QModelIndex &index, int role) const
         return identity.uoid();
     case IdentityNameRole:
         return identity.identityName();
+    case DefaultRole:
+        return identity.isDefault();
+    case Qt::ToolTipRole:
+        return identity.primaryEmailAddress();
     }
 
     return {};
@@ -76,6 +78,7 @@ QHash<int, QByteArray> IdentityModel::roleNames() const
         {UoidRole, QByteArrayLiteral("uoid")},
         {EmailRole, QByteArrayLiteral("email")},
         {IdentityNameRole, QByteArrayLiteral("identityName")},
+        {DefaultRole, QByteArrayLiteral("isDefault")},
     });
     return roles;
 }
